@@ -1,5 +1,4 @@
 package File::SortedSeek;
-
 use strict;
 use warnings;
 use Time::Local;
@@ -11,7 +10,7 @@ use vars qw( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION );
 @EXPORT      = ();
 @EXPORT_OK   = qw( alphabetic numeric find_time get_between get_last );
 %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
-$VERSION     = '0.013';
+$VERSION     = '0.014';
 
 my $descending  = 0;
 my $cuddle      = 0;
@@ -22,8 +21,7 @@ my $exact_match = 0;
 my %months = ( Jan => 0, Feb => 1, Mar => 2, Apr => 3,
                May => 4, Jun => 5, Jul => 6, Aug => 7,
                Sep => 8, Oct => 9, Nov => 10,Dec => 11);
-my $default_rec_sep = ($^O =~ m/win32/i) ? "\015\012" :
-                      ( $^O =~ /mac/i )  ? "\015"     : "\012";
+my $default_rec_sep = qw/\015\012|\015|\012/;
 
 # some subs to set optional vars OO style
 sub set_cuddle      { $cuddle = 1 };
@@ -37,62 +35,55 @@ sub set_verbose     { $silent = 0 };
 sub was_exact       { $exact_match };
 sub error           { $error_msg; };
 
-sub _alphabetic_compare {
-    my ($x, $y) = @_;
-    return $descending ? $y cmp $x : $x cmp $y;
-}
+sub _alphabetic_compare { $descending ? $_[1] cmp $_[0] : $_[0] cmp $_[1] }
 
 sub alphabetic {
     local *FILE     = shift;
     my $string      = shift;
     my $munge_ref   = shift;
-    my $dict_order  = shift;
-    my $ignore_case = shift;
     $error_msg   = '';
-    _look( *FILE, $string, { xfrm => $munge_ref,
-                             comp => \&_alphabetic_compare,
-                             dict => $dict_order,
-                             fold => $ignore_case } );
+    _look( *FILE, $string, \&_alphabetic_compare, $munge_ref );
 }
 
-sub _numeric_compare {
-    my ($x, $y) = @_;
-    return $descending ? $y <=> $x : $x <=> $y;
-}
+sub _numeric_compare { $descending ? $_[1] <=> $_[0] : $_[0] <=> $_[1] }
 
 sub numeric {
     local *FILE     = shift;
     my $number      = shift;
     my $munge_ref   = shift;
     $error_msg   = '';
-    _look( *FILE, $number, { xfrm => $munge_ref, comp => \&_numeric_compare } );
+    _look( *FILE, $number, \&_numeric_compare, $munge_ref  );
 }
 
 sub find_time {
     local *FILE     = shift;
-    my $find        = shift;
+    my $find        = shift || time;
     my $not_gmtime  = shift;
     $error_msg   = '';
-    my $munge_ref   = \&get_epoch_seconds;
-    my $epoch       = get_epoch_seconds( $find );
-    # if $epoch is defined we assume a date string else real epoch secs
-    $find = (defined $epoch) ? $epoch : $find;
-    _look( *FILE, $find, { xfrm => $munge_ref, comp => \&_numeric_compare } );
+    $find = _get_epoch_seconds($find,$not_gmtime) unless $find =~ m/^[\d.]+$/;
+    _look( *FILE, $find, \&_numeric_compare, \&_get_epoch_seconds );
 }
 
-sub get_epoch_seconds {
-    my $line  = shift;
+sub _get_epoch_seconds {
+    my ($line, $not_gmtime) = @_;
   return undef unless defined $line;
-    # grab a scalar localtime looking like string from the line
-    my ($wday,$mon,$mday,$hours,$min,$sec,$year) =
-        $line =~ m/(\w{3})\s+(\w{3})\s+(\d{1,2})\s+(\d\d):(\d\d):(\d\d)\s+(\d{4})/;
+    my ($wday,$mon,$mday,$hours,$min,$sec,$year);
+    # look for asctime format: Tue May 27 15:45:00 2008
+    if ($line =~ m/(\w{3})\s+(\w{3})\s+(\d{1,2})\s+(\d\d):(\d\d):(\d\d)\s+(\d{4})/ ) {
+       ($wday,$mon,$mday,$hours,$min,$sec,$year) = ($1,$2,$3,$4,$5,$6,$7);
+    }
+    # look for apache time format: [21/May/2008:17:49:39 +1000]
+    elsif($line =~ m!\[(\d{1,2})/(\w{3})/(\d{4}):(\d\d):(\d\d):(\d\d)!x ) {
+       ($mday,$mon,$year,$hours,$min,$sec) = ($1,$2,$3,$4,$5,$6);
+    }
     unless ($year) {
         $error_msg = "Unable to find time like string in line:\n$line";
         warn $error_msg unless $silent;
       return undef;
     }
     $mon = $months{$mon};   # convert to numerical months 0 - 11
-  return timegm($sec,$min,$hours,$mday,$mon,$year);
+  return $not_gmtime ? timelocal($sec,$min,$hours,$mday,$mon,$year):
+                       timegm($sec,$min,$hours,$mday,$mon,$year);
 }
 
 sub get_between {
@@ -101,11 +92,10 @@ sub get_between {
     my $finish  = shift || 0;
     my $rec_sep = shift || $default_rec_sep;
     $error_msg   = '';
-    binmode FILE;
     ($begin , $finish) =  ($finish, $begin) if $begin > $finish;
     my $bytes   = $finish - $begin;
-    seek FILE, $begin, 0;
-    my $read = read (FILE, my $buffer, $bytes);
+    sysseek FILE, $begin, 0;
+    my $read = sysread(FILE, my $buffer, $bytes);
     if ( $read < $bytes ) {
         $error_msg  = "Short read\nWanted: $bytes Got: $read\n";
         warn $error_msg unless $silent;
@@ -121,81 +111,66 @@ sub get_last {
     my $num_lines  = shift;
     my $rec_sep    = shift || $default_rec_sep;
     $error_msg   = '';
-    binmode FILE;
-    my(@stat) = stat(FILE) or return undef;
-    my($file_size, $blksize) = @stat[7,11];
+    my @stat = stat(FILE) or return undef;
+    my($size,$blksize) = @stat[7,11];
     $blksize ||= 8192;
-    # grab the first chunk from eof at block offset
-    my $pos = $file_size - (($file_size % $blksize)|| $blksize );
+    # grab the first chunk back from eof at block offset
+    my $pos = $size - (($size % $blksize)|| $blksize );
     my $file = '';
     my ($buf, $lines);
     for(;;) {
         $pos = 0 if $pos < 0;
-        seek(FILE,$pos,0);
-        read(FILE, $buf, $blksize);
+        sysseek(FILE,$pos,0);
+        sysread(FILE, $buf, $blksize) or last; # returns 0 at eof;
         $file = $buf.$file;
         my $lines = () = $file =~ m/$rec_sep/g;
-        last if $lines > $num_lines or $pos == 0;
+      last if $lines > $num_lines or $pos == 0;
         $pos -= $blksize;
     }
     my @file = split /$rec_sep/, $file;
     if ( $num_lines > @file ) {
         $error_msg = "Unable to find $num_lines\n";
-        return wantarray ? @file : \@file;
+        warn $error_msg unless $silent;
+      return wantarray ? @file : \@file;
     }
     else {
         $num_lines = $#file - $num_lines + 1;
-        return wantarray ? @file[$num_lines..$#file] : [@file[$num_lines..$#file]];
+      return wantarray ? @file[$num_lines..$#file] : [@file[$num_lines..$#file]];
    }
 }
 
 # Modified version of Perl Search::Dict's look()
-# Search::Dict not used directly as it does not support cuddle functionality
 
-sub _look{
+sub _look {
     local *FILE = shift;
-    my($key,$params) = @_;
-    my $dict = $params->{dict};
-    my $fold = $params->{fold};
-    my $comp = $params->{comp};
-    my $xfrm = $params->{xfrm};
+    my($key,$comp,$xfrm) = @_;
     local $_;
-    my(@stat) = stat(FILE) or return undef;
+    return undef if not defined $key;
+    my @stat = stat(FILE) or return undef;
     my($size, $blksize) = @stat[7,11];
     $blksize ||= 8192;
-    $key =~ s/[^\w\s]//g if $dict;
-    $key = lc $key       if $fold;
     # find the right block
     my($min, $max) = (0, int($size / $blksize));
     my $mid;
     while ($max - $min > 1) {
         $mid = int(($max + $min) / 2);
         seek(FILE, $mid * $blksize, 0) or return undef;
-        <FILE> if $mid;# probably a partial line
+        <FILE> if $mid; # probably a partial line
         $_ = <FILE>;
-        $_ = $xfrm->($_) if defined $xfrm;
+        $_ = $xfrm->($_) if $xfrm;
         chomp;
-        s/[^\w\s]//g if $dict;
-        $_ = lc $_   if $fold;
-        if (defined($_) && $comp->($_, $key) < 0) {
-            $min = $mid;
-        }
-        else {
-            $max = $mid;
-        }
+        (defined($_) && $comp->($_, $key) < 0) ? $min = $mid : $max = $mid;
     }
     # find the right line
     $min *= $blksize;
     seek(FILE,$min,0) or return undef;
-    <FILE> if $min;
+    <FILE> if $min; # probably a partial line
     my $prev_min = $min;
     for (;;) {
         $min = tell(FILE);
         defined($_ = <FILE>) or last;
-        $_ = $xfrm->($_) if defined $xfrm;
+        $_ = $xfrm->($_) if $xfrm;
         chomp;
-        s/[^\w\s]//g if $dict;
-        $_ = lc $_   if $fold;
         my $cmp = $comp->($_, $key);
         $exact_match = $cmp==0 ? 1 : 0;
         if(!$cuddle and $cmp  >= 0){
@@ -215,11 +190,11 @@ sub _look{
 
 __END__
 
-=head2 NAME
+=head1 NAME
 
-File::SortedSeek -  A Perl module providing fast access to large files
+File::SortedSeek - A Perl module providing fast access to large files
 
-=head2 SYNOPSIS
+=head1 SYNOPSIS
 
   use File::SortedSeek ':all';
   open BIG, $file or die $!;
@@ -266,13 +241,13 @@ File::SortedSeek -  A Perl module providing fast access to large files
   # change the input record separator from the OS default
   @lines = get_last( *BIG, $n, $rec_sep )
 
-=head2 DESCRIPTION
+=head1 DESCRIPTION
 
 File::SortedSeek provides fast access to data from large files. Three
 methods numeric() alphabetic() and find_time() depend on the file data
-being sorted in some way. Logfiles are a typical example of big files that
-are sorted (by date stamp). The get_between() method can be used to get
-a chunk of lines efficiently from anywhere in the file. The required postion(s)
+being sorted in some way. Dictionaries are and obvious example but log files
+are also sorted (by date stamp). The get_between() method can be used to get
+a chunk of lines efficiently from anywhere in the file. The required position(s)
 for the get_between() method are supplied by the previous methods. The
 get_last() method will efficiently get the last N lines of any file, sorted
 or not.
@@ -289,25 +264,14 @@ Remember that old game where you try to guess a number between lets say 0
 and say 128? Let's choose 101 and now try to guess it.
 
 Using a linear search is the same as going 1 higher 2 higher 3 higher ...
-100 higher 101 correct! Consider the geometric approach: 64 higher 96 higher
+100 higher 101 correct! Consider a geometric approach: 64 higher 96 higher
 112 lower 104 lower 100 higher 102 lower - ta da must be 101! This is the
-halving the difference search method and can be applied to any data set where
-we can logically say higher or lower. In other words any sorted data set can
-be searched like this. It is a far more efficient method - see the SPEED
-section for a quick analysis.
+halving the difference  or binary search method and can be applied to any data
+set where we can logically say higher or lower. In other words any sorted data
+set can be searched like this. It is a far more efficient method - see the
+SPEED section for a brief analysis.
 
-=head3 ABSTRACT
-
-Fiel::SortedSeek provides fast access to data from large files. Three
-methods numeric() alphabetic() and find_time() depend on the file data
-being sorted in some way. Logfiles are a typical example of big files that
-are sorted (by date stamp). The get_between() method can be used to get
-a chunk of lines efficiently from anywhere in the file. The required postion(s)
-for the get_between() method are supplied by the previous methods. The
-get_last() method will efficiently get the last N lines of any file, sorted
-or not.
-
-=head3 The two basic methods - numeric() and alphabetic()
+=head2 numeric() and alphabetic() - The two basic methods
 
 There are two basic methods - numeric() to do numeric searches and
 alphabetic() that does alphabetic searches.
@@ -317,17 +281,17 @@ You call the functions like this:
     $tell = numeric( *BIG, $find );
     $tell = alphabetic( *BIG, $find );
 
-These methods take two required arguments. *BIG is a FILEHANDE to read from.
+These methods take two required arguments. *BIG is a FILEHANDLE to read from.
 $find is the item you wish to find. $find must be appropriate to the function
 as the numeric method will make numeric comparisons ( == < > ). Similarly the
 alphabetic method makes string comparisons ( eq lt gt ). You will get strange
-results if you use the wrong method just as you do if you say use < when
-you actually meant lt
+results if you use the wrong method just as you do if you use < when you
+actually meant lt
 
 =head3 Return values with search success and failure
 
 The return value from the numeric() and alphabetic() methods depend on the
-result of the search. If the search fails the return value is undefined.
+result of the search. If the search fails the return value is undef.
 A search can succeed in two ways. If an exact match is found then the
 current file position pointer is set to the beginning of the matching line.
 The return value is the corresponding response from tell(). This means that
@@ -346,12 +310,15 @@ searching for the number 42 in a file like this:
     ..
 
 The number 42 is not actually there but the search will still succeed as it
-is between 40 and 44. By default the file postion pointer is set to the
+is between 40 and 44. By default the file position pointer is set to the
 beginning of the line '44' so the next read from <FILEHANDLE> will return
-this line. If the File::SortedSeek::set_cuddle() function is called then the file
-position pointer will be set to the beginning of line '40' so that the
+this line. If the File::SortedSeek::set_cuddle() function is called then the
+file position pointer will be set to the beginning of line '40' so that the
 first two reads from <FILEHANDLE> will cuddle the in-between value in $find.
 
+You can find out if the match was exact by checking the value returned by
+File::SortedSeek::was_exact() which will be true if the match was exact.
+
 =head3 Adding line munging to make the basic methods more useful
 
 Both the numeric and alphabetic subs take an optional third argument.
@@ -359,46 +326,31 @@ This optional argument is a reference to a subroutine to munge the
 file lines so that suitable values are extracted for comparison to $find.
 
     $tell = numeric( *BIG, $find, \&munge_line );
-    $tell = alphabetic( *BIG, $find, \&munge_line, $dict_order, $ignore_case );
+    $tell = alphabetic( *BIG, $find, \&munge_line );
 
 A good example of this is the find_time() function. This is just an
 implementation of the basic numeric algorithm similar to this.
 
     $tell = numeric ( *BIG, $epoch_seconds, \&get_epoch_seconds );
 
-    sub get_epoch_seconds {
-        use Time::Local;
-        my $line  = shift;
-      return undef unless defined $line;
-        my %months =
-            ( Jan => 0, Feb => 1, Mar => 2, Apr => 3, May => 4,  Jun => 5,
-              Jul => 6, Aug => 7, Sep => 8, Oct => 9, Nov => 10, Dec => 12);
-        # grab a scalar localtime looking like string from the line
-        my ($wday,$mon,$mday,$hours,$min,$sec,$year) =
-            $line =~ m/(\w{3})\s+(\w{3})\s+(\d{1,2})\s+(\d\d):(\d\d):(\d\d)\s+(\d{4})/;
-        unless ($year) {
-            $error_msg = "Unable to find time like string in line:\n$line";
-            warn $error_msg unless $silent;
-          return undef;
-        }
-        $mon = $months{$mon};   # convert to numerical months 0 - 11
-      return timegm($sec,$min,$hours,$mday,$mon,$year);
-    }
-
 As the search is made the test lines are passed to the munging sub. This sub
 needs to return a string or number that we can perform comparison on. In this
-case the sub looks for something that looks like a scalar localtime() string,
-and assuming this is a date passes it to timegm() for conversion to
-epoch seconds and returns this number.
+case the get_epoch_seconds sub looks for something that resembles a date
+string, parses out the hh mm ss dd mm yyyy data, passes it to Time::Local for
+conversion to epoch seconds and returns this number.
 
-The alphabetic function also takes optional 4th and 5th arguments.
+The optional arguments offered by Search::Dict to use dictionary order
+(by removing non word/whitespace chars) and to ignore case are not directly
+supported by File::SortedSeek, however they are easily implemented with a
+simple munge function that does this:
 
-If I<$dict_order> is true, search by dictionary order (ignore anything but word
-characters and whitespace).  The default is honour all characters.
+    sub munge {
+        local $_ = shift;
+        s/[^\w\s]//g;  # removes non word/space chars for dictionary order
+        return lc $_;  # makes comparison case insensistive
+    }
 
-If I<$ignore_case> is true, ignore case.  The default is to honour case.
-
-=head3 find_time()
+=head2 find_time()
 
 The find_time() function is an implementation of the basic numeric method as
 discussed briefly above. You call it like:
@@ -406,12 +358,12 @@ discussed briefly above. You call it like:
     $tell = find_time( *LOG, 'Thu Jan  1 00:42:00 1970' );
     $tell = find_time( *LOG, $epoch_seconds );
 
-You may use either a scalar localtime() like string or epoch seconds. If you
+You may use either an asctime like string or epoch seconds. If you
 use epoch seconds it assumes gmtime. If in doubt use the string as although
 it works internally with gmtime the offsets cancel out and the correct result
 is returned.
 
-=head3 Getting lines from the middle of a file  - get_between()
+=head2 get_between() - Getting lines from the middle of a file
 
 Say you have a logfile and you want to get the log between one date and
 another. You can simply use two calls to the find_time() to get the beginning
@@ -428,14 +380,13 @@ and end positions and then use get_between() to get the lines.
 The get_between() method returns an array in list context as above and a
 reference to an array in scalar context.
 
-This function needs to apply binmode so it splits the lines based on a system
-specific default record separator. This is derived as below:
+This function splits the lines based on a non system specific default record
+separator heuristic. This is defined below:
 
-    my $default_rec_sep = ($^O =~ m/win32/i) ? "\015\012" :
-                          ( $^O =~ /mac/i )  ? "\015"     : "\012";
+    my $default_rec_sep = qw/\015\012|\015|\012/;
 
-You can override this on a per file basis by passing the record separator
-to the get_between() function.
+It should DWIM most of the time. You can override this on a per file basis
+by passing the record separator to the get_between() function.
 
     @lines = get_between( *LOG, $begin, $end, $rec_sep );
 
@@ -443,14 +394,6 @@ Modifying $/ has no effect. Note that *the record separator is not returned*
 in the array. As a result the returned array has effectively had every
 element chomped.
 
-Warning - this method will apply binmode to the FH so line endings
-will possibly not be converted properly if you try to continue to read from
-it. As there is no unbinmode() close the FH afterwards and reopen it if you
-want to read from it. You can seek FH, 0, $end if say you want to read more
-lines after $end.
-
-=head3 Getting the lines from the beginning of a file - get_between()
-
 Using the get_between() method you can efficiently get the lines at the
 beginning of a file. Although you can just read in lines sequentially with
 a while loop this requires that you test each line. If you can find the
@@ -463,8 +406,6 @@ you simply set $begin to 0
     $end    = find_time( *LOG, $finish );
     @lines  = get_between( *LOG, $begin, $end );
 
-=head3 Getting lines from the end of a file - get_between()
-
 You can similarly use get between to get all the lines from a specific point
 up to the end of the file. The end is just the size of the file so:
 
@@ -472,7 +413,7 @@ up to the end of the file. The end is just the size of the file so:
     $end   = -s LOG;
     @lines = get_between( *LOG, $begin, $end );
 
-=head3 Getting lines from the end of a file - get_last()
+=head2 get_last() - Get N lines from the end of a file.
 
 This method does not depend on the file being sorted to work.
 When you use the get_last() method the module estimates how many bytes at
@@ -496,27 +437,18 @@ memory.
     # change the input record separator from the default
     @lines = get_last( *BIG, $n, $rec_sep )
 
-This function needs to apply binmode so it splits the lines based on a system
-specific default record separator. This is derived as below:
+This function splits the lines based on a non system specific default record
+separator heuristic. This is defined below:
 
-    my $default_rec_sep = ($^O =~ m/win32|vms/i) ? "\015\012" :
-                          ( $^O =~ /mac/i ) ? "\015" : "\012";
+    my $default_rec_sep = qw/\015\012|\015|\012/;
 
-You can override this on a per file basis by passing the record separator
-$rec_sep to the get_last() function as shown. Modifying $/ has no effect.
-Note that *the record separator is not returned* in the array. As a
-result the returned array has effectively had every element chomped.
+It should DWIM most of the time. You can override this on a per file basis
+by passing the record separator to the get_between() function.
+Example script in eg/tail.pl
 
-Warning - this method will apply binmode to the FH so line endings
-will possibly not be converted properly if you try to continue to read from
-it. As there is no unbinmode() close the FH afterwards and reopen it if you
-want to read from it. You can seek FH, 0, $end if say you want to read more
-lines after $end.
+=head1 EXPORT
 
-=head2 EXPORT
-
-Nothing is exported by default. The following 5 methods are available for
-import:
+Nothing by default. The following 5 methods are available for import:
 
     alphabetic()
     numeric()
@@ -524,53 +456,64 @@ import:
     get_between()
     get_last()
 
-You can import just the method you want with a:
+You can import just the method(s) you want with:
 
-    use File::SortedSeek 'numeric';
+    use File::SortedSeek qw(numeric);
 
 or all 5  methods using the ':all' tag.
 
     use File::SortedSeek ':all';
 
-=head2 OPTIONS
+=head1 OPTIONS and ACCESSORS
 
 There are some options available via non exported function
 calls. You will need to fully specify the name if you want to use these.
 
-=head3 File::SortedSeek::error()
+=head2 File::SortedSeek::error()
 
 If a function returns undefined there has been an error. error() will
 contain the text of the last error message or a null string if there
 was no error.
 
-=head3 File::SortedSeek::was_exact()
+=head2 File::SortedSeek::was_exact()
 
 was_exact() will return true if an exact match was found. It will be
 false if the match was in between or failed.
 
-=head3 File::SortedSeek::set_cuddle()  File::SortedSeek::set_no_cuddle()
+=head2 File::SortedSeek::set_cuddle()
 
-set_cuddle() changes the default line returned for in between matches  as
-discussed above and set_no_cuddle() restores default behaviour
+set_cuddle() changes the default line returned for in between matches as
+discussed above.
 
-=head3 File::SortedSeek::set_descending() File::SortedSeek::set_ascending()
+=head2 File::SortedSeek::set_no_cuddle()
+
+set_no_cuddle() restores default behaviour
+
+=head2 File::SortedSeek::set_descending()
 
 By default ascending numerical order and alphabetical order are assumed.
 This assumption can be reversed by calling set_descending() and reset
 by calling set_ascending() We need to know the order to seek within the
 file in the correct direction.
 
-=head3 File::SortedSeek::set_silent()  File::SortedSeek::set_verbose()
+=head2 File::SortedSeek::set_ascending()
 
-You can silence or activate error messages by calling these two subs. The
-default is verbose.
+Reset sort order assumption to default.
 
-=head2 SPEED
+=head2 File::SortedSeek::set_verbose()
+
+Activate error messages. This is the default.
+
+=head2 File::SortedSeek::set_silent()
+
+Silence error messages
+
+=head1 SPEED
 
 Here is a table that demonstrates the advantage of using the binary search
 algorithm.
 
-    Num items   Lin avg  Geom avg  Lin:Geom
+    Num items    Lin av    Bin av   Lin:Bin
             2         1         1         1
             4         2         2         1
             8         4         3         1
@@ -593,33 +536,35 @@ algorithm.
       1048576    524288        20     26214
 
 Even though there is an overhead involved with this search this is minor
-as the number of tests required is so much less. Speed increases of 100-1000
+as the number of tests required is so much less. Speed increases of 1000
 of times are typical.
 
 An OO interface slows things down by > 50% so is not used.
 
-=head2 BUGS
+=head1 BUGS
 
-The binmoding of the FH by get_between() and get_last() can not be
-easily avoided.
+All previously known ones have been removed.
 
-=head2 CREDITS
+=head1 CREDITS
 
-Peter (Stig) Edwards for bugfixes and refactoring.
+Peter (Stig) Edwards for bugfixes and getting the refactoring started using
+the cunning expedient of not just sending patches but also a refactored core.
 
 Search::Dict for the basis of the code used to replace the original core
 search function.
 
-=head2 AUTHOR
+=head1 AUTHOR
 
-(c) Dr James Freeman 2000-01 E<lt>airmedical@gmail.comE<gt>
+(c) Dr James Freeman 2000-08 E<lt>airmedical [TA] gmail.comE<gt>
 All rights reserved.
 
-This package is free software and is provided ``as is'' without express or
-implied warranty. It may be used, redistributed and/or modified under the terms
-of the Perl Artistic License (see http://www.perl.com/perl/misc/Artistic.html)
+=head1 LICENSE
 
-=head2 SEE ALSO
+This package is free software and is provided "as is" without express or
+implied warranty. It may be used, redistributed and/or modified under the terms
+of the Perl Artistic License. See the LICENSE file for details.
+
+=head1 SEE ALSO
 
 For details about the mystical significance of the number 42 and how it can
 be applied to Life the Universe and everything see The Hitch Hiker's Guide
